@@ -6,7 +6,7 @@
 # Change 1..1 below to 1..last_test_to_print .
 # (It may become useful if the test is moved to ./t subdirectory.)
 
-BEGIN { $| = 1; print "1..1\n"; }
+BEGIN { $| = 1; print "1..2\n"; }
 END {print "not ok 1\n" unless $loaded;}
 use Mail::Sender;
 $loaded = 1;
@@ -18,3 +18,12 @@ print "ok 1\n";
 # (correspondingly "not ok 13") depending on the success of chunk 13
 # of the test code):
 
+use vars qw($sender);
+
+$sender = new Mail::Sender;
+if (ref $sender) {
+	print "ok 2\n";
+} else {
+	print "not ok 2\n\tfailed to create new Mail::Sender object!\n";
+	exit;
+}
